Other packaged Air Quality Models.
fitNearSiteModel(data, pollutant = "no2", y, x = "rest", elements = NULL, ...)data with model output added as additional
column.
data.frame (or similar) containing data-series
to be modelled; this is expected to contain 'date', 'site'
and pollutant of interest data-series.
The name of the pollutant (in
data) to model, by default 'NO2'.
The name of the monitor site to be modelled,
assumed to be one several names in the site column of
data.
The other sites to use when building the model, the default 'rest' uses all supplied sites except 'y'.
The number of inputs to use in the
site models, can be any number up to length of x or
combination thereof; by default this is set as
length(x):1
extra arguments.
fitNearSiteModel builds an air quality
model for one location using air quality data from nearby
sites.