Finding and testing break-points in conventionally formatted air quality data sets.
findBreakPoints(data, pollutant, h = 0.15, ...)testBreakPoints(data, pollutant, breaks, ...)
findBreakPoints returns a data.frame
of found break-points.
testBreakPoints return a likely break-point/segment
report.
Data source, typically a data.frame
or similar, containing data-series to apply function to
and a paired time-stamped data-series, called date.
Name of time-series, assumed to be
a column in date.
(findBreakPoints only) The data/time window
size to use when looking for breaks in a supplied time-series,
expressed as proportion of time-series (0-1), default 0.15.
other parameters
(testBreakPoints only) data.frame
of The break-points and confidence intervals, typically a
findBreakPoints output.
findBreakPoints uses methods from
strucchange package (see references) and
modifications as suggested by the main author of
strucchange to handle missing cases to find
potential breaks-points in a supplied time-series.
testBreakPoints tests and identifies most likely
break-points using methods proposed for use with
quantBreakPoints and quantBreakSegments
and conventionally formatted air quality data sets.
Regarding strucchange methods see
breakpoints, and:
Achim Zeileis, Friedrich Leisch, Kurt Hornik and Christian Kleiber (2002). strucchange: An R Package for Testing for Structural Change in Linear Regression Models. Journal of Statistical Software, 7(2), 1-38. URL https://www.jstatsoft.org/v07/i02/.
Achim Zeileis, Christian Kleiber, Walter Kraemer and Kurt Hornik (2003). Testing and Dating of Structural Changes in Practice. Computational Statistics & Data Analysis, 44, 109-123.
Regarding missing data handling, see:
URL: https://stackoverflow.com/questions/43243548/strucchange-not-reporting-breakdates.
Regarding testBreakPoints, see:
Ropkins, K., Walker, A., Philips, I., Rushton, C., Clark, T. and Tate, J., Change Detection of Air Quality Time-Series Using the R Package AEQval. Available at SSRN 4267722. https://ssrn.com/abstract=4267722 or http://dx.doi.org/10.2139/ssrn.4267722 Also at: https://karlropkins.github.io/AQEval/articles/AQEval_Intro_Preprint.pdf
find.breaks.